@@ -106,8 +106,8 @@ class DataPreprocessingMixin():
         #Features and target variable: original and encoded
         self._features = None
         self._target_variable = None
-        self._features_type_predictions = None
-        self._target_var_type_prediction = None
+        self._features_type_predictions = pd.DataFrame([])
+        self._target_var_type_prediction = pd.DataFrame([])
         self._encoded_features_model = None
         self._encoded_features_pred = None
         self._target_var_encoded = None
